/*++

Copyright (c) 1992 - 1996 Microsoft Corporation

Module Name:

    BindPrune.c

Abstract:

    This module contains necessary routines to prune the IM_ from the 
    IMSAMP bindings.

Revision History:

        First Pass.

--*/

#define UNICODE
#include "bindprune.h"
#include <stdio.h>
#include <ctype.h>
#include <wchar.h>



BOOL
ImPruneBindings(
    IN  DWORD cArgs,
    IN  LPSTR Args[],
    OUT LPSTR *TextOut
    );


#define MAX_REG_LEN  512





BOOLEAN
DllInitialize (
    IN PVOID DllHandle,
    IN ULONG Reason,
    IN PVOID Context OPTIONAL
    )
{

    switch ( Reason ) {

    case DLL_PROCESS_ATTACH:

        //
        // We don't need to receive thread attach and detach
        // notifications, so disable them to help application
        // performance.
        //

        DisableThreadLibraryCalls( DllHandle );

        return TRUE;

    case DLL_THREAD_ATTACH:

        break;

    case DLL_PROCESS_DETACH:

        break;

    case DLL_THREAD_DETACH:

        break;
    }

    return TRUE;

} 


							   
BOOL
ImPruneBindings(
    IN  DWORD cArgs,
    IN  LPSTR Args[],
    OUT LPSTR *TextOut
    )
{
HKEY Im;                      			// the handle to the reg key we want
long RetVal;                       			// varible for error reporting
WCHAR inbuf[MAX_REG_LEN];              // Character buffer for holding the MULTI_sz strings read from the registry   	
DWORD bufsz = MAX_REG_LEN * sizeof(WCHAR);
DWORD type = REG_MULTI_SZ;
DWORD indexin,indexout;				   // index pointers for buffer manipulation


	UNREFERENCED_PARAMETER(cArgs);	  // I left the input args in incase anybody 
	UNREFERENCED_PARAMETER(Args);	  // wants to modify this DLL to pass in the
	UNREFERENCED_PARAMETER(*TextOut );// registry key to modify. I don't use the args


	 // open the IM Linkage key
     RetVal = RegOpenKeyEx( HKEY_LOCAL_MACHINE,
			           TEXT("SYSTEM\\CurrentControlSet\\Services\\IM\\Linkage"),
					   0,
					   KEY_ALL_ACCESS,
					   &Im); 
		           
     if(RetVal != ERROR_SUCCESS)
	 {
		 // Something wrong with the registry open. Process the error here
	     RegCloseKey(HKEY_LOCAL_MACHINE);
		 return FALSE;
	 }
	 
	 // We have the key open, read the Bind string
	 RegQueryValueEx( Im,
					  TEXT("Bind"),
					  NULL,
					  &type,
                      (UCHAR *)inbuf,
					  &bufsz);

     // Now we should have something that looks like:
	 // \Device\IM_NdisWan6 '0' \Device\IM_el903 '0'.......in the buffer.
     // Strip the IM_'s from it

     // inbuf is the registry MULTI_SZ that holds the strings with the IM_'s
	 // bufsz is the size (in bytes, not unicode characters) of the buffer
	 // on return, inbuf will be stripped of the IM_'s, and bufsz will be updated accordingly
	 // If there are no IM_'s, then this function will not modify the buffer.

	 indexin = indexout = 0;
	 while(indexin < bufsz/2) //bufsz is reported in bytes, the buffer is WCHARs 
	 {
       inbuf[indexout] = inbuf[indexin];
       if(inbuf[indexin] == L'\\')
	   {
		    if(inbuf[indexin+1] == L'I')
			{
				if(inbuf[indexin+2] == L'M')
				{
					if(inbuf[indexin+3] == L'_')
					{
						indexin +=3; // if we find an IM_, then bump the read pointer to read past it
					}
				}
			}
	   }
	   
	   indexin++;
	   indexout++;
      

     }  
     indexout--;	      // undo the last bump
     bufsz = indexout*2;  // save the size , in bytes, of the WCHAR buffer
	 
	 

	 // Now inbuf should have the IM_'s stripped, resave it to the registry.
	 RetVal = RegSetValueEx(Im,
		           TEXT("Bind"),
				   0,
				   REG_MULTI_SZ,
				   (UCHAR *)inbuf,
                   bufsz); 




      RegCloseKey(HKEY_LOCAL_MACHINE);


     return(TRUE);    
}

