/*++

Copyright (c) 1996  Microsoft Corporation

Module Name:

    osdep.h

Abstract:

    defines for OS specific routines

Author:

    Jim Mateer

Revision History:

--*/

#ifndef _OSDEP_
#define _OSDEP_

#if BINARY_COMPATIBLE

//
// shortest timer period in microsecs
//

#define TIMER_GRANULARITY    1000

typedef ULONG KSPIN_LOCK, *PKSPIN_LOCK;       // For ExInterlockedAddLargeInteger

#define ExInterlockedAddLargeInteger( _add, _inc, _lock ) (_add)->QuadPart += (_inc).QuadPart

#define PAGED_CODE()

//
// interlocked routines degenerate to the trivial case
//

#define InterlockedIncrement( _a ) (++(*(_a)))

//
// MM system size stuff. Define away the query routine to make medium
// the default size
//

typedef enum _MM_SYSTEM_SIZE {
    MmSmallSystem,
    MmMediumSystem,
    MmLargeSystem
} MM_SYSTEMSIZE;

#define MmQuerySystemSize()     MmMediumSystem

#else // BINARY_COMPATIBLE

//
// shortest timer period in microsecs
//

#define TIMER_GRANULARITY    10000

#endif      // BINARY_COMPATIBLE

//
// convert from microseconds to 100ns units and vice versa
//

#define IM_TO_OS_TIME( _time )  (( (LONGLONG)_time ) * 10 )

#define OS_TO_IM_TIME( _time )  (( _time ) / 10 )

//
// convert from IM's microseconds to millisecs
//

#define IM_TIME_TO_MILLISECS( _time ) (( _time ) / 1000 )

#endif /* _OSDEP_ */

/* end osdep.h */
